html5lib: An HTML parser
========================

Description
-----------

HTML parser based on the WHATWG HTML specification.

License
-------

MIT License


Upstream Contact
----------------

Home Page: https://github.com/html5lib/html5lib-python/issues

Dependencies
------------

Python, webencodings, six
